;-------------------------------------------------------------------------;
;                                    TIGA                                 ;
;          Copyright (C) 1988-1990  Texas Instruments Incorporated.       ;
;                            All Rights Reserved                          ;
;-------------------------------------------------------------------------;
;   TIGA - Include file                                                   ;
;-------------------------------------------------------------------------;
;                                                                         ;      
;  file            typedefs.inc (usoft-Assembler version of typedefs.h)   ;
;                                                                         ;
;   description     This file contains type definitions used in both      ;
;                   Applications Interface.                               ;
;                   This file should be included in any Microsoft-        ;
;                   Assembly program accessing data of these types.       ;
;                                                                         ;
;-------------------------------------------------------------------------;


;--------------------------------------------------------------------------;
;  CURSOR structure definition                                             ;
;                                                                          ;
;      This structure contains cursor description information.             ;
;--------------------------------------------------------------------------;
CURSOR          STRUC
cursor_hot_x            DW      ?       ; offset from top...  
cursor_hot_y            DW      ?       ; ...left-hand corner 
cursor_width            DW      ?       ; array width         
cursor_height           DW      ?       ; array height        
cursor_pitch            DW      ?       ; linear difference between rows                      
cursor_color            DD      ?       ; cursor shape color
cursor_mask_rop         DW      ?       ; cursor mask rop
cursor_shape_rop        DW      ?       ; cursor shape rop
cursor_mask_color       DD      ?       ; cursor mask color
cursor_data             DD      ?       ; pointer to cursor data in GSP memory
CURSOR          ENDS 

                                                                                  
;--------------------------------------------------------------------------;
;  PATTERN structure definition                                            ;
;                                                                          ;
;      This structure contains pattern description information.            ;
;--------------------------------------------------------------------------;
PATTERN         STRUC
pattern_width   DW      ?       ; width in bits      
pattern_height  DW      ?       ; height in bits      
pattern_depth   DW      ?       ; depth in bits       
pattern_data    DD      ?       ; pointer to pattern data in GSP memory
PATTERN         ENDS 


;--------------------------------------------------------------------------;
;  PALET structure definition                                              ;
;                                                                          ;
;      This structure contains the rgb and intensity components for a      ;
;      palette entry.                                                      ;
;--------------------------------------------------------------------------;
PALET           STRUC
palet_r         DB      ?
palet_g         DB      ?
palet_b         DB      ?
palet_i         DB      ?
PALET           ENDS 



;--------------------------------------------------------------------------;
;  OFFSCREEN structure definitions                                         ;
;                                                                          ;
;      These structures contain definitions of offscreen work areas        ;
;--------------------------------------------------------------------------;
OFFSCREEN_AREA  STRUC
offscreen_addr  DD      ?   ; address in gsp space of an offscreen work area 
offscreen_xext  DW      ?   ; x extension in the current screen pixel size   
offscreen_yext  DW      ?   ; y extension using default screen pitch         
OFFSCREEN_AREA  ENDS 


;--------------------------------------------------------------------------;
;  MODEINFO structure definition                                           ;
;                                                                          ;
;      This structure contains information pertaining to the current mode  ; 
;      of operation.                                                       ;
;--------------------------------------------------------------------------;
MODEINFO        STRUC                   
modeinfo_disp_pitch         DD      ?       ; display pitch y::x              
modeinfo_disp_vres          DW      ?       ; vertical resolution (pixels)    
modeinfo_disp_hres          DW      ?       ; horizontal resolution (pixels)  
modeinfo_screen_wide        DW      ?       ; screen width                    
modeinfo_screen_high        DW      ?       ; screen height                   
modeinfo_disp_psize         DW      ?       ; pixel size                      
modeinfo_pixel_mask         DD      ?       ; pixel mask                      
modeinfo_palet_gun_depth    DW      ?       ; # of bits per gun                  
modeinfo_palet_size         DD      ?       ; number of palette entries       
modeinfo_palet_inset        DW      ?       ; offset from frame start to data 
modeinfo_num_pages          DW      ?       ; number of display pages         
modeinfo_num_offscrn_areas  DW      ?       ; number off offscreen work areas 
modeinfo_wksp_addr          DD      ?       ; address of offscreen workspace 
modeinfo_wksp_pitch         DD      ?       ; pitch of offscreen workspace
modeinfo_silicon_capability DW      ?       ; flag for VRAM block write etc
modeinfo_color_class        DW      ?       ; Color Type Flags
modeinfo_red_mask           DD      ?       ; Red Mask
modeinfo_green_mask         DD      ?       ; Red Mask
modeinfo_blue_mask          DD      ?       ; Red Mask
modeinfo_x_aspect           DW      ?       ; Windows X Aspect
modeinfo_y_aspect           DW      ?       ; Windows X Aspect
modeinfo_diagonal_aspect    DW      ?       ; Windows Diagonal Aspect
MODEINFO        ENDS

;--------------------------------------------------------------------------;
;  CONFIG structure definition                                             ;
;                                                                          ;
;      This structure contains the current hardware operating              ;
;      configuration.                                                      ;
;--------------------------------------------------------------------------;
CONFIG          STRUC
config_version_number       DW  ?
config_comm_buff_size       DD  ?
config_sys_flags            DD  ?     
config_device_rev           DD  ?    
config_num_modes            DW  ?     
config_current_mode         DW  ?  
config_program_mem_start    DD  ?
config_program_mem_end      DD  ?
config_display_mem_start    DD  ?
config_display_mem_end      DD  ?
config_stack_size           DD  ?    
config_shared_mem_size      DD  ?
config_shared_host_addr     DD  ?
config_shared_gsp_addr      DD  ?
config_mode     DB SIZE MODEINFO DUP (?)
CONFIG          ENDS 


;--------------------------------------------------------------------------;
;  ENVIRONMENT structure definition                                        ;
;                                                                          ;
;      This structure contains the current values of environment global    ;
;      variables.                                                          ;
;--------------------------------------------------------------------------;
ENVIRONMENT     STRUC
environment_xyorigin            DD      ?       ; xy drawing origin      
environment_pensize             DD      ?       ; pensize height::width  
environment_srcbm               DD      ?       ; source bitmap struct   
environment_dstbm               DD      ?       ;   dest bitmap struct   
environment_stylemask           DD      ?       ; styled line patn mask  
ENVIRONMENT     ENDS 
                        
;------------------------------------------------------------------------;
;   MODULE structure definition                                          ;
;                                                                        ;
;   This structure defines the data associated with a function module.   ;
;------------------------------------------------------------------------;
MODULE          STRUC
module_ListAddr            DD      ?
module_MallocAddr          DD      ?
module_MallocBytes         DD      ?
module_NumFuncs            DW      ?
module_Flags               DW      ?
MODULE          ENDS 

;------------------------------------------------------------------------;
;   FONT structure definition                                            ;
;                                                                        ;
;   This structure defines the data associated with a font               ;
;------------------------------------------------------------------------;
FONT            STRUC
font_magic      DW      ?       ;  font type code                                
font_length     DD      ?       ;  Length of font in bytes                      
font_facename   DB 30 DUP (?)
font_deflt      DW      ?       ;  ASCII code of default character                 
font_first      DW      ?       ;  ASCII code of first character                 
font_last       DW      ?       ;  ASCII code of last character                  
font_maxwide    DW      ?       ;  maximum character width                       
font_maxkern    DW      ?       ;  maximum character kerning amount              
font_charwide   DW      ?       ;  Width of characters (0 if proportional)       
font_avgwide    DW      ?       ;  Average width of characters                   
font_charhigh   DW      ?       ;  character height                              
font_ascent     DW      ?       ;  ascent (how far above base line)              
font_descent    DW      ?       ;  descent (how far below base line)             
font_leading    DW      ?       ;  leading (row bottom to next row top)          
font_rowpitch   DD      ?       ;  bits per row of char patterns                 
font_oPatnTbl   DD      ?       ;  Bit offset to PatnTbl (from bof)              
font_oLocTbl    DD      ?       ;  Bit offset to LocTbl (from bof)               
font_oOwTbl     DD      ?       ;  Bit offset to OWTbl (from bof)                
FONT            ENDS 

;-----------------------------------------------------------------------;
;   FONTINFO structure definition                                       ;
;-----------------------------------------------------------------------;
FONTINFO        STRUC   
fontinfo_facename       DB 30 DUP (?)
fontinfo_deflt          DW      ?       ;  ASCII code of default character                 
fontinfo_first          DW      ?       ;  ASCII code of first character                 
fontinfo_last           DW      ?       ;  ASCII code of last character                  
fontinfo_maxwide        DW      ?       ;  maximum character width                       
fontinfo_avgwide        DW      ?       ;  Average width of characters                   
fontinfo_maxkern        DW      ?       ;  Max character kerning amount                  
fontinfo_charwide       DW      ?       ;  Width of characters (0=proportional)          
fontinfo_charhigh       DW      ?       ;  character height                              
fontinfo_ascent         DW      ?       ;  ascent (how far above base line)              
fontinfo_descent        DW      ?       ;  descent (how far below base line)             
fontinfo_leading        DW      ?       ;  leading (row bottom to next row top)          
fontinfo_fontptr        DD      ?       ;  address of font in gsp memory                */
fontinfo_id             DW      ?       ;  id of font (set at install time)             */
FONTINFO        ENDS 

;--------------------------------------------------------------------------;
;  MONITORINFO10 structure definition                                      ;
;                                                                          ;
;      Note this structure is specific to the 34010                        ; 
;      This structure contains video timing parameters.                    ;
;--------------------------------------------------------------------------;
MONITORINFO10   STRUC           
monitor_hesync10        DW      ?  
monitor_heblnk10        DW      ?  
monitor_hsblnk10        DW      ?  
monitor_htotal10        DW      ?  
monitor_vesync10        DW      ?  
monitor_veblnk10        DW      ?  
monitor_vsblnk10        DW      ?  
monitor_vtotal10        DW      ?  
monitor_dpyctl10        DW      ?  
monitor_screen_delay10  DW      ?
monitor_flags10         DW      ?
MONITORINFO10   ENDS

;--------------------------------------------------------------------------;
;  PAGE10 structure definitions                                            ;
;                                                                          ;
;      Note this structure is specific to the 34010                        ; 
;      These structures contain definitions used to implement multiple     ;
;      display pages.  The information in these structures is used to      ;
;      display a given page.                                               ;
;--------------------------------------------------------------------------;
PAGE10          STRUC           
page_BaseAddr10 DD      ?   ; Base address of start of page               
page_DpyStart10 DW      ?   ; Value loaded in Display Start i/o register  
page_DummyPad10 DW      ?   ; 16 bits to pad structure to power of 2 size 
PAGE10          ENDS 

;--------------------------------------------------------------------------;
;  MONITORINFO20 structure definition                                      ;
;                                                                          ;
;      Note this structure is specific to the 34020                        ; 
;      This structure contains video timing parameters.                    ;
;--------------------------------------------------------------------------;
MONITORINFO20   STRUC           
monitor_vesync20        DW      ?  
monitor_hesync20        DW      ?  
monitor_veblnk20        DW      ?  
monitor_heblnk20        DW      ?  
monitor_vsblnk20        DW      ?  
monitor_hsblnk20        DW      ?  
monitor_vtotal20        DW      ?  
monitor_htotal20        DW      ?  
monitor_dpyctl20        DW      ?  
monitor_dincl20         DW      ?  
monitor_dinch20         DW      ?  
monitor_heserr20        DW      ?  
monitor_dpymsk20        DW      ?  
monitor_screen_delay20  DW      ?
monitor_flags20         DW      ?
MONITORINFO20   ENDS

;--------------------------------------------------------------------------;
;  PAGE20 structure definitions                                            ;
;                                                                          ;
;      Note this structure is specific to the 34020                        ; 
;      These structures contain definitions used to implement multiple     ;
;      display pages.  The information in these structures is used to      ;
;      display a given page.                                               ;
;--------------------------------------------------------------------------;
PAGE20          STRUC           
page_BaseAddr20 DD      ?   ; Base address of start of page               
page_DpyStart20 DD      ?   ; Value loaded in Display Start i/o register  
PAGE20          ENDS 
